"""Pathway IO models, organized by domain.

Conventions:
- Keep this package `__init__` intentionally light (avoid barrel exports).
- Prefer importing from leaf modules (e.g. `pathways.models.agent`).
"""

__all__: list[str] = []
